//
//  MFServiceConfiguration.h
//  MFAuthLib
//
//  Created by MicroFocus on 4/25/17.
//  Copyright © 2017 Microfocus. All rights reserved.
//

#import <AppAuth/AppAuth.h>

/*! @brief This extends the @c OIDServiceConfiguration class and adds few additional properties.
 */
@interface MFServiceConfiguration : OIDServiceConfiguration

/*! @brief OAuth UserInfo endpoint.
 */
@property (nonatomic) NSURL *userinfoEndpoint;

/*! @brief Oauth Revocation endpoint.
 */
@property (nonatomic) NSURL *revocationEndpoint;

/*! @brief Logout endpoint at the Identity / Authorization Server.
 */
@property (nonatomic) NSURL *browserLogoutEndpoint;

/*! @brief A Convinience Initializer
 @param OIDServiceConfig Initialize with the @c OIDServiceConfiguration object.
 */
- (instancetype) initWithOIDServiceConfiguration:(OIDServiceConfiguration *) OIDServiceConfig;

/*! @brief Initializer.
 @param authorizationEndpoint OAuth authorization endpoint.
 @param tokenEndpoint OAuth Token endpoint.
 @param revocationEndpoint OAuth token revocation endpoint.
 @param userinfoEndpoint OAuth userinfo endpoint.
 @param browserLogoutEndpoint Logout endpoint at the Identity / Authorization server.
 */
- (instancetype) initWithAuthorizationEndpoint:(NSURL *)authorizationEndpoint
                                 tokenEndpoint:(NSURL *)tokenEndpoint
                            revocationEndpoint:(NSURL *)revocationEndpoint
                              userinfoEndpoint:(NSURL *)userinfoEndpoint
                              browserLogoutEndpoint:(NSURL *)browserLogoutEndpoint;

/*! @brief Initializer.
 @param authorizationEndpoint OAuth authorization endpoint.
 @param tokenEndpoint OAuth Token endpoint.
 @param revocationEndpoint OAuth token revocation endpoint.
 @param userinfoEndpoint OAuth userinfo endpoint.
 @param registrationEndpoint OpenID Connect registration endpoint.
 @param browserLogoutEndpoint Logout endpoint at the Identity / Authorization server.
 */
- (instancetype) initWithAuthorizationEndpoint:(NSURL *)authorizationEndpoint
                                 tokenEndpoint:(NSURL *)tokenEndpoint
                            revocationEndpoint:(NSURL *)revocationEndpoint
                              userinfoEndpoint:(NSURL *)userinfoEndpoint
                         registrationEndpoint:(NSURL *) registrationEndpoint
                         browserLogoutEndpoint:(NSURL *)browserLogoutEndpoint;

/*! @brief Initializer.
 @param discoveryDocument OIDC Discovery document endpoint.
 @param revocationEndpoint OAuth token revocation endpoint.
 @param browserLogoutEndpoint Logout endpoint at the Identity / Authorization server.
*/
- (instancetype)initWithDiscoveryDocument:(OIDServiceDiscovery *) discoveryDocument
                       revocationEndpoint:(NSURL *) revocationEndpoint
                    browserLogoutEndpoint:(NSURL *)browserLogoutEndpoint;

@end
